==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/DDFIELDIDSLIST_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour DDFIELDIDSLIST_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="DDFIELDIDSLIST_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GRIDTABLENAME" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GRIDFIELDNAME"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DDFIELDID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DDFIELDIDSLIST_Type", propOrder = {
    "gridtablename",
    "gridfieldname",
    "ddfieldid"
})
public class DDFIELDIDSLIST_Type {

    @XmlElement(name = "GRIDTABLENAME")
    protected String gridtablename;
    @XmlElement(name = "GRIDFIELDNAME", required = true)
    protected String gridfieldname;
    @XmlElement(name = "DDFIELDID")
    protected Long ddfieldid;

    /**
     * Obtient la valeur de la propriété gridtablename.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGRIDTABLENAME() {
        return gridtablename;
    }

    /**
     * Définit la valeur de la propriété gridtablename.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGRIDTABLENAME(String value) {
        this.gridtablename = value;
    }

    /**
     * Obtient la valeur de la propriété gridfieldname.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGRIDFIELDNAME() {
        return gridfieldname;
    }

    /**
     * Définit la valeur de la propriété gridfieldname.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGRIDFIELDNAME(String value) {
        this.gridfieldname = value;
    }

    /**
     * Obtient la valeur de la propriété ddfieldid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getDDFIELDID() {
        return ddfieldid;
    }

    /**
     * Définit la valeur de la propriété ddfieldid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setDDFIELDID(Long value) {
        this.ddfieldid = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/DDFIELDIDSLIST_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for DDFIELDIDSLIST_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="DDFIELDIDSLIST_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GRIDTABLENAME" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GRIDFIELDNAME"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DDFIELDID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DDFIELDIDSLIST_Type", propOrder = {
    "gridtablename",
    "gridfieldname",
    "ddfieldid"
})
public class DDFIELDIDSLIST_Type {

    @XmlElement(name = "GRIDTABLENAME")
    protected String gridtablename;
    @XmlElement(name = "GRIDFIELDNAME", required = true)
    protected String gridfieldname;
    @XmlElement(name = "DDFIELDID")
    protected Long ddfieldid;

    /**
     * Gets the value of the gridtablename property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGRIDTABLENAME() {
        return gridtablename;
    }

    /**
     * Sets the value of the gridtablename property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGRIDTABLENAME(String value) {
        this.gridtablename = value;
    }

    /**
     * Gets the value of the gridfieldname property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGRIDFIELDNAME() {
        return gridfieldname;
    }

    /**
     * Sets the value of the gridfieldname property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGRIDFIELDNAME(String value) {
        this.gridfieldname = value;
    }

    /**
     * Gets the value of the ddfieldid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getDDFIELDID() {
        return ddfieldid;
    }

    /**
     * Sets the value of the ddfieldid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setDDFIELDID(Long value) {
        this.ddfieldid = value;
    }

}
